pub fn realloc_any(array: ArrayRef, metrics: &ColumnarMetrics) -> ArrayRefExpand description
Rebuild the given array ref, dropping null buffers on non-nullable fields.
pub fn realloc_any(array: ArrayRef, metrics: &ColumnarMetrics) -> ArrayRefRebuild the given array ref, dropping null buffers on non-nullable fields.